@@ -16,8 +16,9 @@ class MyParser(argparse.ArgumentParser):
         sys.exit(2)
 
 
-sub_name = 'dckrsub.yml'
-compose_name = 'docker-compose.yml'
+sub_names = [x.strip() for x in os.environ.get('PORTMGR_SUB_NAME', 'dckrsub.yml').split(',')]
+compose_names = [x.strip() for x in os.environ.get('PORTMGR_COMPOSE_NAME', 'docker-compose.yml, docker-compose.yaml').split(',')]
+
 # sub_scheme_name = 'dckrsub.schema.yml'
 
 src_path = os.path.dirname(os.path.abspath(__file__))
@@ -45,13 +46,14 @@ action_list = []
 
 
 def addCommand(cur_directory):
-    relative_dir = os.path.relpath(cur_directory, base_directory)
-    if relative_dir == '.':
-        relative_dir = os.path.basename(os.path.normpath(cur_directory))
-    action_list.append({
-        'directory': cur_directory,
-        'relative': relative_dir
-    })
+    if not any(action['directory'] == cur_directory for action in action_list):
+        relative_dir = os.path.relpath(cur_directory, base_directory)
+        if relative_dir == '.':
+            relative_dir = os.path.basename(os.path.normpath(cur_directory))
+        action_list.append({
+            'directory': cur_directory,
+            'relative': relative_dir
+        })
 
 
 def read_yaml(path):
@@ -64,20 +66,21 @@ def read_yaml(path):
 
 def traverse(cur_directory):
     # print("Traversing in " + cur_directory)
-    sub_path = os.path.join(cur_directory, sub_name)
-    compose_path = os.path.join(cur_directory, compose_name)
+    for sub_name in sub_names:
+        sub_path = os.path.join(cur_directory, sub_name)
+        compose_paths = [os.path.join(cur_directory, name) for name in compose_names]
 
-    # print("Checking file at " + sub_path)
-    if os.path.isfile(sub_path):  # has sub folders
-        # print("Has sub folders!")
-        # sub_folders = dckrjsn.read_json(sub_path, sch = sub_scheme)
-        sub_folders = read_yaml(sub_path)
-        for sub_folder in sub_folders:
-            # print("Checking out " + sub_folder)
-            next_directory = os.path.join(cur_directory, sub_folder)
-            traverse(next_directory)
-    elif os.path.isfile(compose_path):  # has a docker-compose file
-        addCommand(cur_directory)
+        # print("Checking file at " + sub_path)
+        if os.path.isfile(sub_path):  # has sub folders
+            # print("Has sub folders!")
+            # sub_folders = dckrjsn.read_json(sub_path, sch = sub_scheme)
+            sub_folders = read_yaml(sub_path)
+            for sub_folder in sub_folders:
+                # print("Checking out " + sub_folder)
+                next_directory = os.path.join(cur_directory, sub_folder)
+                traverse(next_directory)
+        elif any(os.path.isfile(path) for path in compose_paths):  # has a docker-compose file
+            addCommand(cur_directory)
 
 
 def main():
@@ -145,13 +148,19 @@ def main():
         else:
             exit(1)
 
+        failed_list = []
+
         for action in action_list_sorted:
             origWD = os.getcwd()
             newWD = action['directory']
             os.chdir(newWD)
             print('-> ' + action["relative"])
             if cmd_function(action) != 0:  # execute the function through reflection
-                exit(1)
+                failed_list.append(action)
             os.chdir(origWD)
+        if failed_list:
+            print('Failed containers:')
+            for action in failed_list:
+                print('- ' + action['relative'])
 
     exit(0)
